@@ -2,7 +2,7 @@
 from django.conf.urls import patterns, include, url
 
 
-from djhcup_staging.views import obj_detail, obj_inventory, index, run_batch
+from djhcup_staging.views import obj_detail, obj_inventory, index, run_batch, batch_from_unprocessed
 #from djhcup_staging.views import file_detail, file_discover, file_match, file_inventory
 #from djhcup_staging.views import ibatch_detail
 
@@ -28,6 +28,7 @@ ibatch_patterns = patterns('',
 stbatch_patterns = patterns('',
     url(r'(?P<obj_id>\d+)/$', obj_detail, {'obj_type': 'StagingBatch'}, name='stb_detail'),
     url(r'(?P<obj_id>\d+)/run/$', run_batch, {'obj_type': 'StagingBatch'}, name='stb_run'),
+    url(r'unprocessed_batch/$', batch_from_unprocessed),
     url(r'$', obj_inventory, {'obj_type': 'StagingBatch'}, name='stb_inv'),
 )
 
@@ -41,7 +42,6 @@ tbl_patterns = patterns('',
         name='tbl-inventory-filtered'
         ),
     url(r'$', obj_inventory, {'obj_type': 'StagingTable'}, name='tbl_inv'),
-    #url(r'unprocessed_batch/$', 'create_batch_from_unprocessed'),
 )
 
 col_patterns = patterns('',
