@@ -71,8 +71,9 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
     Creates batches for unprocessed files, including batches with
     changed input availability.
     """
-    batches = []
     now = datetime.datetime.utcnow().replace(tzinfo=utc).strftime("%Y%m%d%H%M%S")
+    b = StagingBatch(name='Unprocessed, circa {now}'.format(now=now), description='Conversions include...')
+    b.save()
 
     states = misc.states()
     years = misc.years()
@@ -87,12 +88,12 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
             for con in conversions:
                 req_in = con['req_in']
                 cat_out = con['cat_out']
-                name = '{inputs} to {cat_out} {now}' \
-                    .format(inputs=req_in, cat_out=cat_out, now=now)
-                description = 'Batch of all incomplete {ds} {inputs} to {cat_out} StagingTables as of {now}.' \
+                description = '\n{ds} {inputs} to {cat_out}.' \
                     .format(ds=ds, inputs=req_in, cat_out=cat_out, now=now)
-                b = StagingBatch(name=name, description=description)
+                b.description = b.description + description
                 b.save()
+                #b = StagingBatch(name=name, description=description)
+                #b.save()
                 for st in states:
                     for yr in years:
                         # instantiate, but do not save/add to batch til end
@@ -194,8 +195,13 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                         
                         else:
                             # check for completed StagingQueue built matching cat_out and state-year already
+                            # I know this variable name implies this should be querying StagingTable objects.
+                            # It should not.
+                            # Ideally it would and then do some reverse lookup stuff on related StagingQueue objects,
+                            # but everytime I try to do that I eff it up. So this is what we have.
                             st_tbl_qs = StagingQueue.objects \
-                                .filter(category=cat_out, complete__isnull=False)
+                                .filter(category=cat_out, complete__isnull=False,
+                                        stg_output__isnull=False, void=False)
                             
                             reqd_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in reqs if x is not False]
                             opt_predicates = [('%s__isnull' % CAT_IN_TO_ATTR[x], False) for x in opts if x is not False]
@@ -241,22 +247,21 @@ def unprocessed_batches(conversions=STAGING_CONVERSIONS,
                                 # and a boolean for whether the old one has been dropped.
                                 # that could be pruned manually on a periodic basis, or whatevs.
                                 # would probably need to review dependencies/parent-child tbl relations
-                            
-                set_length = len(b.stagingqueue_set.all())
-                if set_length == 0:
-                    b.log('Found no out-of-date conversions for StagingBatch {pk}. The batch will be marked as void.' \
-                        .format(pk=b.pk))
-                    b.void = True
-                    b.save()
-                else:
-                    b.log('Created StagingBatch {pk} with {length} files'.format(pk=b.pk, length=set_length))
-                
-                batches.append(b)
-            
+                                
         else:
             default_logger.info("Found no StagingTable objects with traceable heredity to parent data source with abbreviation {ds}. Therefore, the entire data source family was skipped.".format(ds=ds))
     
-    return batches
+    set_length = len(b.stagingqueue_set.all())
+    
+    if set_length == 0:
+        b.log('Found no out-of-date conversions for StagingBatch {pk}. The batch will be marked as void.' \
+            .format(pk=b.pk))
+        b.void = True
+        b.save()
+    else:
+        b.log('Created StagingBatch {pk} with {length} files'.format(pk=b.pk, length=set_length))
+    
+    return b
 
 
 def unimported_batch():
